pub type Cipher = (u8, Vec<u8>);Expand description
A tuple containing a 5-bit base stored as a u8 and a body whose length equals the plaintext length. You can use your own algorithm to combine them, or use ShortCrypt::encrypt_to_url_component or ShortCrypt::encrypt_to_qr_code_alphanumeric to produce a random-like string.